## bestFit

[![Documentation Status](https://readthedocs.org/projects/pip/badge/?version=stable)](https://pip.pypa.io/en/stable/?badge=stable)
[![Language grade: Python](https://img.shields.io/lgtm/grade/python/g/sebass-but-ab/bestFit.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/sebass-but-ab/bestFit/context:python)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)
[![PyPi Version](https://img.shields.io/pypi/v/bestFit.svg)](https://pypi.python.org/pypi/bestFit/)

Simple wrapper to plot the best fit line for a given set of coordinates.

Installation:
``pip install bestFit``

In a .py file, write ``import bestFit.main``, then see the docs for the list of available classes and methods, which is the section following ``quickstart``.

Docs: https://bestfit.readthedocs.io/en/latest/

Github page: https://github.com/sebass-but-ab/bestFit
